#!/usr/bin/perl
#######################################################################
# SnowlistConfig - config file parsing and loading
#
# $Id: SnowlistConfig.pm 293 2004-10-30 15:18:00Z kiza $
#
# Load settings and DB access password from config file
#
# Copyright Oliver Feiler 2004 <kiza@gmx.net>
# http://kiza.kcore.de/software/snowlist/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#######################################################################

package SnowlistConfig;
my(@EXPORT) = qw(LoadConfig);
use strict;
use English;

#######################################################################

my($configdir) = $ENV{'HOME'}."/.snowlist";

#######################################################################

sub LoadConfig {
	my($template) = shift;
	my(%config);
	
	if ((!defined($template)) && ($PROGRAM_NAME !~ /snowlistExpire/)) {
		die "No ListID given!\n";
	}
	
	# Defaults
	$config{'dbname'} = "";
	$config{'dbhost'} = undef;
	$config{'dbusername'} = "";
	$config{'dbpassword'} = "";
	$config{'maxthreads'} = 30;
	$config{'maxitemsperthread'} = 20;
	$config{'compressoutput'} = "yes";
	$config{'compressionlevel'} = 8;
	$config{'msg_expire'} = "30 days";
	
	open (CONFIG, "$configdir/config") or die "Cannot read config from \"$configdir/config\". Please see the documentation!\n";
	while (<CONFIG>) {
		if (/^[#\[\n]/) {
			next;
		}
		chomp;

		/^(.*?)\s+(.*)$/;
		if ($1 eq "dbname") {
			$config{'dbname'} = $2;
		} elsif ($1 eq "dbhost") {
			$config{'dbhost'} = $2;
		} elsif ($1 eq "dbusername") {
			$config{'dbusername'} = $2;
		} elsif ($1 eq "dbpassword") {
			$config{'dbpassword'} = $2;
		} elsif ($1 eq "maxthreads") {
			$config{'maxthreads'} = $2;
		} elsif ($1 eq "maxitemsperthread") {
			$config{'maxitemsperthread'} = $2;
		} elsif ($1 eq "compressoutput") {
			$config{'compressoutput'} = $2;
		} elsif ($1 eq "compressionlevel") {
			$config{'compressionlevel'} = $2;
		} elsif ($1 eq "msg_expire") {
			$config{'msg_expire'} = $2;
		}
	}
	close (CONFIG);
	
	if ($PROGRAM_NAME !~ /snowlistExpire/) {
		open (TEMPLATE, "$configdir/$template.config") or die "Cannot read config file for ListID \"$configdir/$template.config\". Please see the documentation!\n";
		while (<TEMPLATE>){
			chomp;
			
			/^(.*?)\s+(.*)$/;
			if ($1 eq "title") {
				$config{'feedtitle'} = $2;
			} elsif ($1 eq "link") {
				$config{'feedlink'} = $2;
			} elsif ($1 eq "description") {
				$config{'feeddescription'} = $2;
			} elsif ($1 eq "outputfile") {
				$config{'outputfile'} = $2;
			} elsif ($1 eq "maxthreads") {
				$config{'maxthreads'} = $2;
			} elsif ($1 eq "maxitemsperthread") {
				$config{'maxitemsperthread'} = $2;
			}
		}
		close (TEMPLATE);
	}
	return \%config;
}


sub db_connect {
	my ($config) = @_;
	return DBI->connect("dbi:Pg:dbname=" . $config->{'dbname'} . ";host=" . $config->{'dbhost'},
	                    $config->{'dbusername'}, $config->{'dbpassword'},
	                    {RaiseError => 1, AutoCommit => 1, pg_enable_utf8 => 1});
}
